DNBelab™ C Series

Single-Cell ATAC Analysis Report V$pipeversion

Sample Information : $sample_info

Estimated number of cells
  The total number of barcodes identified as cells.
Median fragments per cell
  The median number of fragments per cell.
Median faction of fragments overlapping peaks
  The median fraction of fragments overlapping peaks.
Median fraction of fragments overlapping TSSs
  The median fraction of fragments overlapping TSSs.

- $estimate_num_of_cell

  Estimated number of cells

- $median_frag_per_cell

  ###### Median fragments per cell

- $median_frac_peaks

  ###### Median fraction of fragments overlapping peaks

- $median_frac_tss

  ###### Median fraction of fragments overlapping TSSs

Sample

Sample ID

$sample_id

Species

$species

Reference path

$ref_path
Sequencing

Total number of read pairs
  Total number of read pairs that were assigned to this library in demultiplexing.
Fraction of read pairs with a valid barcode
  Fraction of read pairs with barcodes that match the whitelist after barcode correction.

Total number of reads pairs

$read_pairs

Fraction of read pairs with a valid barcode

$frac_valid_barcode
Mapping

Reads mapped to genome
  The number of reads that align to the reference genome.
Mitochondria reads ratio
  The number of reads that aligned to the mitochondrial chromosome.

Reads mapped to genome

$map_rate

Mitochondria reads ratio

$mit_rate
Cell

Read number threshold
  The number of reads per barcode identified as cell.
Bead number threshold
  The total number of barcodes identified as cells.
Jaccard threshold
  Threshold of jaccard index for collapsing bead barcodes to cell barcodes.
(plot) Bead Barcode Knee
  Knee plot of number of fragments for all the barcodes in the library. This number is used to call cells.
(plot) Jaccard Overlap Knee
  Knee plot of D2C overlap score per barcode pair.
(plot) Number of beads per droplet
  Histograms of number of beads per droplet.
(plot) Saturation
  This plot shows the Sequencing Saturation metric as a function of downsampled sequencing depth in mean reads per cell, up to the observed sequencing depth. Sequencing Saturation is a measure of the observed library complexity, and approaches 1.0 (100%) when all fragments have been sequenced. The slope of the curve near the endpoint can be interpreted as an upper bound to the benefit to be gained from increasing the sequencing depth beyond this point.

Bead Barcode Knee

Read number threshold

$bead_thres

Bead number threshold

$bead_number

Jaccard Overlap Knee

Jaccard threshold

$jaccard_thres
$plot1
$plot2

Number of beads per droplet

Saturation

$plot3
$plot10
Libary QC

Mean fraction of fragments overlapping TSSs
  Mean fraction of fragments (that passed all filters) overlapping transcription start sites, as defined by the GENCODE basic annotation.
Called peak number
  The number of peaks called.
Mean fraction of fragments overlapping peaks
  Mean fraction of fragments (that passed all filters) overlapping the set of peaks called for the library.
Fraction of nucleosome-free-regions
  The fraction of fragments (that passed all filters) overlapping nucleosome-free-regions.
Fraction of fragments mono-nucleosome regions
  The fraction of fragments (that passed all filters) overlapping mono-nucleosome regions.
Percent duplicates
  Fraction of all the sequenced read pairs that come from cell barcodes and are deemed to be PCR duplicates due to alignment to the same genomic position as another read pair in the library.
(plot) Single Cell targeting peaks
  (left) The plot of log10 unique fragment in violin.
  (middle) The plot of TSS proportion in violin.
  (right) The plot of FRIP score in violin.
(plot) Insert Size Distribution
  Insert size distribution in linear scale.
(plot) Enrichment around TSS
  The TSS profile is the summed accessibility signal (defined as number of cut sites per base) in a window of 2,000 bases around all the annotated TSSs, normalized by the minimum signal in the window.

Targeting

Mean fraction of fragments overlapping TSSs
$frac_frag_overlap

Called peak number

$call_peak_number

Mean fraction of fragments overlapping peaks

$overlap_call_peak

Insert Size Distribution

Fraction of nucleosome-free regions

$nc_free_region

Fraction of fragments mono-nucleosome regions

$mono_nc_region

Library Complexity

Percent of duplicates

$percent_dup

Single Cell targeting peaks

$plot4

Insert Size Distribution

$plot5

Enrichment around TSS

$plot6
Cell Clustering

Plot
  (left) Scatter plot of barcodes annotated as cells, colored by automatically computed clusters via graph clustering.
  (right) Scatter plot of barcodes annotated as cells, colored by number of fragments in the barcode.

$plot7
$plot8